@@ -4,7 +4,7 @@ import requests
 import time
 import uuid
 import logging
-from typing import Optional, List, Dict, Any, Callable
+from typing import Optional, List, Dict, Any, Callable, Union
 from .types import (
     Message,
     CreateMemoryRequest,
@@ -30,7 +30,7 @@ from .exceptions import (
 class MemoryStackClient:
     """Client for interacting with MemoryStack API"""
     
-    SDK_VERSION = "1.0.2"
+    SDK_VERSION = "1.0.3"
 
     def __init__(
         self,
@@ -345,51 +345,64 @@ class MemoryStackClient:
 
         return data
 
-    def create_memory(
+    def add(
         self,
-        messages: List[Message],
+        content: Union[str, List[Message], List[Dict[str, str]]],
         user_id: Optional[str] = None,
         metadata: Optional[Dict[str, Any]] = None,
     ) -> CreateMemoryResponse:
         """
-        Create new memories from conversation messages
+        Add a memory - the simplest way to store information.
+        
+        Examples:
+            # Simple text
+            client.add("User prefers dark mode")
+            
+            # With user ID (for B2B apps)
+            client.add("User prefers dark mode", user_id="user_123")
+            
+            # Conversation format
+            client.add([
+                {"role": "user", "content": "I love Python"},
+                {"role": "assistant", "content": "Great choice!"}
+            ])
         
         Args:
-            messages: List of conversation messages
+            content: Text string or list of messages
             user_id: Optional end user ID for B2B use cases
             metadata: Optional metadata dictionary
             
         Returns:
             CreateMemoryResponse with created memory IDs
         """
-        # Validate before API call
+        # Normalize content to messages
+        if isinstance(content, str):
+            messages = [{"role": "user", "content": content}]
+        elif isinstance(content, list):
+            messages = []
+            for msg in content:
+                if isinstance(msg, dict):
+                    messages.append(msg)
+                else:
+                    messages.append({"role": msg.role, "content": msg.content})
+        else:
+            raise ValidationError("Content must be a string or list of messages")
+        
+        # Validate
         if not messages:
             raise ValidationError("At least one message is required")
-        
         if len(messages) > 100:
             raise ValidationError("Maximum 100 messages per request")
-        
-        # Normalize messages to dictionaries
-        normalized_messages = []
         for msg in messages:
-            if isinstance(msg, dict):
-                if not msg.get('role') or not msg.get('content'):
-                    raise ValidationError(f"Message missing role or content: {msg}")
-                normalized_messages.append(msg)
-            else:
-                if not msg.role or not msg.content:
-                    raise ValidationError(f"Message missing role or content: {msg}")
-                normalized_messages.append({"role": msg.role, "content": msg.content})
+            if not msg.get('role') or not msg.get('content'):
+                raise ValidationError(f"Message missing role or content: {msg}")
         
-        payload = {
-            "messages": normalized_messages,
-        }
+        # Build payload
+        payload = {"messages": messages}
         if user_id is not None:
             payload["user_id"] = user_id
         if metadata is not None:
             payload["metadata"] = metadata
-        
-        # Automatically include agent context if available
         if self.session_id:
             payload["session_id"] = self.session_id
         if self.agent_name:
@@ -397,25 +410,15 @@ class MemoryStackClient:
         if self.agent_type:
             payload["agent_type"] = self.agent_type
 
-        # Use /memories/agents endpoint if agent context is provided
         endpoint = f"{self.base_url}/memories/agents" if self.agent_name else f"{self.base_url}/memories"
-        
         response = self._make_request('POST', endpoint, json=payload)
         data = self._handle_response(response)
 
-        # Store agent_id and project_id from response for future use
         if data.get("agent_id"):
             self.agent_id = data["agent_id"]
         if data.get("project_id"):
             self.project_id = data["project_id"]
 
-        # Handle response structure
-        if not isinstance(data, dict):
-            raise Exception(f"Invalid response format: {type(data)}")
-        
-        if "success" not in data:
-            raise Exception(f"Response missing 'success' field. Got: {list(data.keys())}")
-
         return CreateMemoryResponse(
             success=data.get("success", True),
             memories_created=data.get("memories_created", 1),
@@ -427,6 +430,15 @@ class MemoryStackClient:
             project_id=data.get("project_id"),
         )
 
+    def create_memory(
+        self,
+        messages: List[Message],
+        user_id: Optional[str] = None,
+        metadata: Optional[Dict[str, Any]] = None,
+    ) -> CreateMemoryResponse:
+        """Deprecated: Use add() instead - simpler API"""
+        return self.add(messages, user_id=user_id, metadata=metadata)
+
     def list_memories(
         self,
         user_id: Optional[str] = None,
@@ -553,181 +565,86 @@ class MemoryStackClient:
             error=data.get("error"),
         )
 
-    # Helper methods
-
-    def add_conversation(
+    def search(
         self,
-        user_message: str,
-        assistant_message: str,
+        query: str,
         user_id: Optional[str] = None,
-        metadata: Optional[Dict[str, Any]] = None,
-    ) -> CreateMemoryResponse:
+        limit: int = 10,
+    ) -> Dict[str, Any]:
         """
-        Helper: Create memory from simple text conversation
+        Search memories - find relevant information.
+        
+        Examples:
+            # Simple search
+            results = client.search("user preferences")
+            
+            # With user ID (for B2B apps)
+            results = client.search("user preferences", user_id="user_123")
+            
+            # With limit
+            results = client.search("user preferences", limit=5)
         
         Args:
-            user_message: User's message
-            assistant_message: Assistant's response
-            user_id: Optional end user ID
-            metadata: Optional metadata
+            query: Search query
+            user_id: Optional end user ID filter
+            limit: Maximum results (1-50, default: 10)
             
         Returns:
-            CreateMemoryResponse
+            Dict with 'success', 'count', and 'results' keys
         """
-        messages = [
-            Message(role="user", content=user_message),
-            Message(role="assistant", content=assistant_message),
-        ]
-        return self.create_memory(messages, user_id, metadata)
+        if not query or not query.strip():
+            raise ValidationError("Search query is required")
+        
+        if not isinstance(limit, int) or limit < 1 or limit > 50:
+            raise ValidationError("Limit must be between 1 and 50")
+        
+        params = {
+            "query": query,
+            "limit": limit,
+            "mode": "hybrid",  # Best default mode - user doesn't need to know
+        }
+        if user_id:
+            params["user_id"] = user_id
+        
+        response = self._make_request('GET', f"{self.base_url}/memories/search", params=params)
+        data = self._handle_response(response)
+        
+        return {
+            "success": data.get("success", True),
+            "count": len(data.get("results", [])),
+            "results": data.get("results", [])
+        }
 
-    def add_message(
-        self,
-        message: str,
-        user_id: Optional[str] = None,
-        metadata: Optional[Dict[str, Any]] = None,
-    ) -> CreateMemoryResponse:
-        """
-        Helper: Create memory from single user message
-        
-        Args:
-            message: User's message
-            user_id: Optional end user ID
-            metadata: Optional metadata
-            
-        Returns:
-            CreateMemoryResponse
-        """
-        messages = [Message(role="user", content=message)]
-        return self.create_memory(messages, user_id, metadata)
+    # Legacy methods - kept for backward compatibility but deprecated
+    def add_conversation(self, user_message: str, assistant_message: str, user_id: Optional[str] = None, metadata: Optional[Dict[str, Any]] = None) -> CreateMemoryResponse:
+        """Deprecated: Use add() instead"""
+        return self.add([{"role": "user", "content": user_message}, {"role": "assistant", "content": assistant_message}], user_id=user_id, metadata=metadata)
 
-    def get_user_memories(
-        self, user_id: str, limit: int = 20
-    ) -> ListMemoriesResponse:
-        """
-        Helper: List all memories for a specific user
-        
-        Args:
-            user_id: End user ID
-            limit: Maximum results per page
-            
-        Returns:
-            ListMemoriesResponse
-        """
+    def add_message(self, message: str, user_id: Optional[str] = None, metadata: Optional[Dict[str, Any]] = None) -> CreateMemoryResponse:
+        """Deprecated: Use add() instead"""
+        return self.add(message, user_id=user_id, metadata=metadata)
+
+    def get_user_memories(self, user_id: str, limit: int = 20) -> ListMemoriesResponse:
+        """Deprecated: Use list_memories() instead"""
         return self.list_memories(user_id=user_id, limit=limit)
 
     def get_personal_memories(self, limit: int = 20) -> ListMemoriesResponse:
-        """
-        Helper: List personal memories (no end user)
-        
-        Args:
-            limit: Maximum results per page
-            
-        Returns:
-            ListMemoriesResponse
-        """
+        """Deprecated: Use list_memories() instead"""
         return self.list_memories(user_id="self", limit=limit)
 
     def get_all_memories(self, limit: int = 20) -> ListMemoriesResponse:
-        """
-        Helper: List all memories across all users
-        
-        Args:
-            limit: Maximum results per page
-            
-        Returns:
-            ListMemoriesResponse
-        """
+        """Deprecated: Use list_memories() instead"""
         return self.list_memories(user_id="all", limit=limit)
 
     def search_memories(
         self,
         query: str,
         user_id: Optional[str] = None,
-        agent_id: Optional[str] = None,
-        conversation_id: Optional[str] = None,
-        session_id: Optional[str] = None,
-        team_id: Optional[str] = None,
         limit: int = 10,
-        mode: str = "hybrid",
-        threshold: Optional[float] = None,
-        memory_type: Optional[str] = None,
-        min_confidence: Optional[float] = None,
+        **kwargs  # Accept but ignore legacy params like mode, threshold, etc.
     ) -> Dict[str, Any]:
-        """
-        Search memories using hybrid retrieval (vector + text search)
-        
-        Args:
-            query: Search query
-            user_id: Optional end user ID filter
-            agent_id: Filter by agent ID (filters metadata->agent_id)
-            conversation_id: Filter by conversation ID (filters metadata->conversation_id)
-            session_id: Filter by session ID (filters metadata->session_id)
-            team_id: Filter by team ID (filters metadata->team_id)
-            limit: Maximum results (1-50)
-            mode: Search mode ('hybrid', 'vector', or 'text')
-            threshold: Similarity threshold (0.1-0.99)
-            memory_type: Optional memory type filter
-            min_confidence: Optional minimum confidence threshold
-            
-        Returns:
-            Dict with 'success', 'count', 'mode', and 'results' keys
-            
-        Note:
-            agent_id, conversation_id, session_id, and team_id filter on the
-            JSONB metadata column, not separate indexed columns.
-        """
-        # Validate query
-        if not query or not query.strip():
-            raise ValidationError("Search query is required and cannot be empty")
-        
-        # Validate mode
-        if mode not in ['hybrid', 'vector', 'text']:
-            raise ValidationError(
-                f'Invalid search mode: "{mode}". Must be "hybrid", "vector", or "text"'
-            )
-        
-        # Validate limit
-        if not isinstance(limit, int) or limit < 1 or limit > 50:
-            raise ValidationError(
-                f"Invalid limit: {limit}. Must be an integer between 1 and 50"
-            )
-        
-        # Validate threshold
-        if threshold is not None:
-            if not isinstance(threshold, (int, float)) or threshold < 0.1 or threshold > 0.99:
-                raise ValidationError(
-                    f"Invalid threshold: {threshold}. Must be a number between 0.1 and 0.99"
-                )
-        
-        # Validate min_confidence
-        if min_confidence is not None:
-            if not isinstance(min_confidence, (int, float)) or min_confidence < 0 or min_confidence > 1:
-                raise ValidationError(
-                    f"Invalid min_confidence: {min_confidence}. Must be a number between 0 and 1"
-                )
-        """
-        Search memories using hybrid retrieval (vector + text search)
-        
-        Args:
-            query: Search query
-            user_id: Optional end user ID filter
-            agent_id: Filter by agent ID (filters metadata->agent_id)
-            conversation_id: Filter by conversation ID (filters metadata->conversation_id)
-            session_id: Filter by session ID (filters metadata->session_id)
-            team_id: Filter by team ID (filters metadata->team_id)
-            limit: Maximum results (1-50)
-            mode: Search mode ('hybrid', 'vector', or 'text')
-            threshold: Similarity threshold (0.1-0.99)
-            memory_type: Optional memory type filter
-            min_confidence: Optional minimum confidence threshold
-            
-        Returns:
-            Dict with 'success', 'count', and 'results' keys
-            
-        Note:
-            agent_id, conversation_id, session_id, and team_id filter on the
-            JSONB metadata column, not separate indexed columns.
-        """
+        """Deprecated: Use search() instead - simpler API"""
+        return self.search(query, user_id=user_id, limit=limit)
         params = {
             "query": query,
             "limit": limit,
